@@ -129,7 +129,9 @@ def Gamma_22(T: float, T1_1: float, T1_2: float, T1_new1: float, T1_new2: float,
     """
     if isinstance(molecule1, MoleculeMultiT) and isinstance(molecule2, MoleculeMultiT)\
             and isinstance(molecule_new1, MoleculeMultiT) and isinstance(molecule_new2, MoleculeMultiT):
-        return raw_Gamma_22(T, T1_1, T1_2, T1_new1, T1_new2, molecule1.vibr[1], molecule2.vibr[1], molecule_new1.vibr[1],
+        return raw_Gamma_22(T, T1_1, T1_2, T1_new1, T1_new2, molecule1.vibr_zero, molecule2.vibr_zero,
+                            molecule_new1.vibr_zero, molecule_new2.vibr_zero,
+                            molecule1.vibr[1], molecule2.vibr[1], molecule_new1.vibr[1],
                             molecule_new2.vibr[1], molecule1.Z_vibr(T, T1_1), molecule2.Z_vibr(T, T1_2),
                             molecule_new1.Z_vibr(T, T1_new1), molecule_new2.Z_vibr(T, T1_new2), molecule1.mass,
                             molecule2.mass, molecule_new1.mass, molecule_new2.mass, molecule1.form, molecule2.form,
@@ -271,7 +273,9 @@ def raw_Gamma_VV(T: float, T1_1: float, T1_2: float, vibr_one1: float, vibr_one2
     return 1.0 - exp(add / (constants.k * T))
 
 
-def raw_Gamma_22(T: float, T1_1: float, T1_2: float, T1_new1: float, T1_new2: float, vibr_one1: float, vibr_one2: float,
+def raw_Gamma_22(T: float, T1_1: float, T1_2: float, T1_new1: float, T1_new2: float,
+                 vibr_zero1: float, vibr_zero2: float, vibr_zero_new1: float, vibr_zero_new2: float,
+                 vibr_one1: float, vibr_one2: float,
                  vibr_one_new1: float, vibr_one_new2: float, Z_int1: float, Z_int2: float, Z_int_new1: float,
                  Z_int_new2: float, mass1: float, mass2: float, mass_new1: float, mass_new2: float, form1: float,
                  form2: float, form_new1: float, form_new2: float, n_molecule1: float, n_molecule2: float,
@@ -292,6 +296,14 @@ def raw_Gamma_22(T: float, T1_1: float, T1_2: float, T1_new1: float, T1_new2: fl
         the temperature of the first vibrational level of the molecule M3
     T1_new2 : float
         the temperature of the first vibrational level of the molecule M4
+    vibr_zero1 : float
+        the dimensional non-zero energy of the 0 vibrational level of the molecule M1
+    vibr_zero2 : float
+        the dimensional non-zero energy of the 0 vibrational level of the molecule M2
+    vibr_zero_new1 : float
+        the dimensional non-zero energy of the 0 vibrational level of the molecule M3
+    vibr_zero_new2 : float
+        the dimensional non-zero energy of the 0 vibrational level of the molecule M4
     vibr_one1 : float
         the dimensional energy of the first vibrational level of the molecule M1
     vibr_one2 : float
@@ -351,7 +363,8 @@ def raw_Gamma_22(T: float, T1_1: float, T1_2: float, T1_new1: float, T1_new2: fl
     add = Z_int1 * Z_int2 / (Z_int_new1 * Z_int_new2)
     add *= (n_molecule1 * n_molecule2) / (n_molecule_new1 * n_molecule_new2)
     add *= (mass1 * mass2 / (mass_new1 * mass_new2)) ** 1.5
-    add *= np.exp(form_new1 / kT + form_new2 / kT - form1 / kT - form2 / kT)
+    add *= np.exp(form_new1 / kT + form_new2 / kT - form1 / kT - form2 / kT + vibr_zero_new1 / kT + vibr_zero_new2 / kT
+                  - vibr_zero1 / kT - vibr_zero2 / kT)
     add *= np.exp(vibr_one1 * i * (1.0 / (constants.k * T1_1) - 1.0 / kT)
                   + vibr_one2 * k * (1.0 / (constants.k * T1_2) - 1.0 / kT)
                   - vibr_one_new1 * i_new * (1.0 / (constants.k * T1_new1) - 1.0 / kT)
